@@ -14,14 +14,14 @@
 #include <QRandomGenerator>
 #include <QTimerEvent>
 #include <KGamePopupItem>
-#include <KGameRenderer>
-#include <KgTheme>
-#include <KgThemeProvider>
+#include <KGameGraphicsViewRenderer>
+#include <KGameTheme>
+#include <KGameThemeProvider>
 #include <KNotification>
 
 const int UpdateInterval = 40;
 
-Game::Game(KDiamond::GameState *state, KGameRenderer *renderer)
+Game::Game(KDiamond::GameState *state, KGameGraphicsViewRenderer *renderer)
     : m_timerId(-1)
     , m_board(new KDiamond::Board(renderer))
     , m_gameState(state)
@@ -34,7 +34,7 @@ Game::Game(KDiamond::GameState *state, KGameRenderer *renderer)
     const int minSize = m_board->gridSize();
     setSceneRect(0.0, 0.0, minSize, minSize);
     connect(this, &Game::sceneRectChanged, this, &Game::updateGraphics);
-    connect(renderer->themeProvider(), &KgThemeProvider::currentThemeChanged, this, &Game::updateGraphics);
+    connect(renderer->themeProvider(), &KGameThemeProvider::currentThemeChanged, this, &Game::updateGraphics);
     addItem(m_board);
     //init messenger
     m_messenger->setMessageOpacity(0.8);
@@ -138,7 +138,7 @@ void Game::updateGraphics()
     m_board->setTransform(t);
     //render background
     QPixmap pix = m_board->renderer()->spritePixmap(QStringLiteral("kdiamond-background"), sceneSize);
-    const KgTheme *theme = m_board->renderer()->theme();
+    const KGameTheme *theme = m_board->renderer()->theme();
     const bool hasBorder = theme->customData(QStringLiteral("HasBorder")).toInt() > 0;
     if (hasBorder) {
         const qreal borderPercentage = theme->customData(QStringLiteral("BorderPercentage")).toFloat();
@@ -236,7 +236,8 @@ void Game::timerEvent(QTimerEvent *event)
         //copy selection info into another storage (to allow the user to select the next two diamonds while the cascade runs)
         m_swappingDiamonds = points;
         m_jobQueue << KDiamond::RemoveRowsJob; //We already insert this here to avoid another conditional statement.
-    } //fall through
+        [[fallthrough]];
+    }
     case KDiamond::RevokeSwapDiamondsJob:
         //invoke movement
         KNotification::event(QStringLiteral("move"));
